@@ -21,6 +21,7 @@
 from __future__ import absolute_import
 
 import re
+from distutils.version import LooseVersion
 from enum import Enum
 
 from requests.structures import CaseInsensitiveDict
@@ -419,9 +420,10 @@ class K8sClusterController(AbstractWaitableResourceController):
         if datafabric:
             data["datafabric"] = True
             data["datafabric_name"] = datafabric_name
-        if len(addons) == 0:
-            # TODO persistent storage was deprecated in 5.x?
-            # check server version rather than addons
+        if LooseVersion(
+            self.client.config.get()["objects"]["bds_global_version"]
+        ) <= LooseVersion("5.1"):
+            # persistent_storage was deprecated after 5.1
             data["persistent_storage"] = (
                 {
                     "local": persistent_storage_local,
@@ -584,10 +586,17 @@ class K8sClusterController(AbstractWaitableResourceController):
         )
         return response.json()
 
-    def import_generic_cluster(
-        self, name, description, pod_dns_domain, server_url, ca, bearer_token
+    def import_cluster(
+        self,
+        cluster_type,
+        name,
+        description,
+        pod_dns_domain,
+        server_url,
+        ca,
+        bearer_token,
     ):
-        """Import a generic k8s cluster.
+        """Import a k8s cluster.
 
         TODO
 
@@ -599,10 +608,18 @@ class K8sClusterController(AbstractWaitableResourceController):
         ------
         APIException
         """
+        assert cluster_type in [
+            "generic",
+            "eks",
+            "aks",
+            "gke",
+            "pks",
+        ], 'cluster_type must be either "generic", "eks", "aks", "gke", "pks"'
+
         data = {
             "label": {"name": name, "description": description},
             "pod_dns_domain": pod_dns_domain,
-            "type": "generic",
+            "type": cluster_type,
             "sysadmin_data": {
                 "server_url": server_url,
                 "ca": ca,
@@ -618,6 +635,19 @@ class K8sClusterController(AbstractWaitableResourceController):
         )
         return CaseInsensitiveDict(response.headers)["Location"]
 
+    def import_generic_cluster(
+        self, name, description, pod_dns_domain, server_url, ca, bearer_token
+    ):
+        return self.import_cluster(
+            "generic",
+            name,
+            description,
+            pod_dns_domain,
+            server_url,
+            ca,
+            bearer_token,
+        )
+
     def import_generic_cluster_with_json(self, json):
         """Import a generic k8s cluster.
 
